@@ -59,9 +59,10 @@ def BrowserGCM(headless=True):
     try:
         browser_cm = init_browser(headless)
         yield browser_cm
-    except Exception as exc:
-        print(f'Failed init browser ?? {exc}')
-        raise BrowserException(f'Failed init browser ?? {exc}')
+    except BrowserException as exc:
+        # print(f'Failed init browser ?? {exc}')
+        # raise BrowserException(f'Failed init browser ?? {exc}')
+        raise
     finally:
         if browser_cm:
             browser_cm.quit()
